@@ -19,7 +19,8 @@
 
 #ifndef _COMPARE_DB_H_INCLUDED
 #define _COMPARE_DB_H_INCLUDED
+#include "list.h"
 
-int compare_db(list*)
+void compare_db(list*);
 
 #endif
