@@ -25,16 +25,17 @@
 #include <unistd.h>
 #endif
 
-#include "getopt.h"
 #include "aide.h"
-#include "error.h"
+#include "cipher.h"
 #include "commandconf.h"
+#include "compare_db.h"
 #include "db_config.h"
 #include "db_file.h"
-#include "list.h"
-#include "gen_list.h"
-#include "cipher.h"
 #include "do_md.h"
+#include "error.h"
+#include "gen_list.h"
+#include "getopt.h"
+#include "list.h"
 
 db_config* conf;
 
@@ -46,7 +47,9 @@ void usage(void)
 	  "\n"
 	  "Commands:\n"
 	  "-i\n--init\n\tInitialize the database\n"
-	  "-C\n--check\n\tCheck the database\n"	  
+	  "-C\n--check\n\tCheck the database\n"
+	  "-u\n--update\n\t"
+	  "Check and update the database non-interactively.\n"
 	  "-v\n--version\n\t"
 	  "Show version of AIDE and compilation options.\n"
 	  "-h\n--help\n\tShow this help message\n"
@@ -58,7 +61,7 @@ void usage(void)
 	  "-A \"config_stuff\"\n--after=\"config_stuff\"\n\t"
 	  "After config_file is read use these options.\n"
 	  "-r reporter\n--report=reporter\n\t"
-	  "Where output is written to.\n"
+	  "Where report output is written to.\n"
 	  "-Vverbosity_level\n--verbose=verbosity_level\n\t"
 	  "Level of debug messages.\n"
 	  "\n"
@@ -93,11 +96,12 @@ int read_param(int argc,char**argv)
     { "report", required_argument, NULL, 'r'},
     { "init", no_argument, NULL, 'i'},
     { "check", no_argument, NULL, 'C'},
+    { "update", no_argument, NULL, 'u'},
     { NULL }
   };
 
   while(1){
-    option = getopt_long(argc, argv, "hV::vc:B:A:r:e:f:iC", options, &i);
+    option = getopt_long(argc, argv, "hV::vc:B:A:r:e:f:iCu", options, &i);
     if(option==-1)
       break;
     switch(option)
@@ -172,7 +176,8 @@ int read_param(int argc,char**argv)
 	if(conf->action==0){
 	  conf->action=DO_INIT;
 	}else {
-	  error(0,"Cannot have init and compare or multiple inits\n");
+	  error(0,
+		"Cannot have multiple commands on a single commandline.\n");
 	  exit(INVALID_ARGUMENT_ERROR);
 	};
 	break;
@@ -181,7 +186,18 @@ int read_param(int argc,char**argv)
 	if(conf->action==0){
 	  conf->action=DO_COMPARE;
 	}else {
-	  error(0,"Cannot have init and compare or multiple inits\n");
+	  error(0,
+		"Cannot have multiple commands on a single commandline.\n");
+	  exit(INVALID_ARGUMENT_ERROR);
+	};
+	break;
+      }
+      case 'u': {
+	if(conf->action==0){
+	  conf->action=DO_INIT|DO_COMPARE;
+	}else {
+	  error(0,
+		"Cannot have multiple commands on a single commandline.\n");
 	  exit(INVALID_ARGUMENT_ERROR);
 	};
 	break;
@@ -282,14 +298,8 @@ void setdefaults_after_config()
 
 int main(int argc,char**argv)
 {
-  int retval=0;
   list* newlst=NULL;
-  list* plst=NULL;
-  list* nlst=NULL;
-  list* elst=NULL;
-  rx_rule* rxr=NULL;
   list* l=NULL;
-  db_line* line=NULL;
   int errorno=0;
 
   setdefaults_before_config();
@@ -314,7 +324,15 @@ int main(int argc,char**argv)
   }
 
   setdefaults_after_config();
-
+  
+  if(cmpurl(conf->db_in_url,conf->db_out_url)==RETOK){
+    error(5,"WARNING:Input and output database urls are the same.\n");
+    if((conf->action&DO_INIT)&&(conf->action&DO_COMPARE)){
+      error(0,"Input and output database urls cannot be the same"
+	    "when doing database update\n");
+      exit(INVALID_ARGUMENT_ERROR);
+    }
+  };
   newlst=gen_list(conf->selrxlst,conf->negrxlst,conf->equrxlst);
   newlst=do_md(newlst);
 
