@@ -23,6 +23,7 @@
 #include <stdarg.h>
 #include <errno.h>
 #include "db_config.h"
+#include "error.h"
 
 FILE* be_init(int inout,url_t* u)
 {
@@ -54,15 +55,15 @@ FILE* be_init(int inout,url_t* u)
       error(0,"Illegal file descriptor value:%s\n",u->value);
     }
     fh=fdopen(a,inout?"r":"w");
-    if(fh=NULL){
+    if(fh==NULL){
       error(0,"Couldn't reopen file descriptor %i\n",a);
     }
     return fh;
   }
   default:{
     error(0,"Unsupported backend:%i", u->type);
+    return NULL;
   }    
   }
-
-
+  /* Not reached */
 }
