@@ -19,6 +19,7 @@
  
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <errno.h>
 #include "db.h"
 #include "db_file.h"
@@ -99,13 +100,23 @@ byte* base64tobyte(char* src,int len)
 db_line* db_char2line(char** ss,db_config* conf){
 
   int i;
-  char* tmp=NULL;
   db_line* line=(db_line*)malloc(sizeof(db_line)*1);
 
   line->md5=NULL;
   line->sha1=NULL;
   line->rmd160=NULL;
   line->tiger=NULL;
+  line->perm=0;
+  line->uid=0;
+  line->gid=0;
+  line->atime=0;
+  line->ctime=0;
+  line->mtime=0;
+  line->inode=0;
+  line->nlink=0;
+  line->size=0;
+  line->filename=NULL;
+  line->attr=0;
 
   for(i=0;i<conf->db_in_size;i++){
     switch (conf->db_in_order[i]) {
