@@ -189,7 +189,30 @@ char** db_readline_file(db_config* conf){
     
     case TNEWLINE : {
       
-      error(0,"Not enough parameters in db:%i\n",db_lineno);
+      if (i==0) {
+	i--;
+	break;
+      }
+      
+      /*  */
+
+      error(0,"Not enough parameters in db:%i. Trying to continue.\n",
+	    db_lineno);
+      for(a=0;a<i;a++){
+	free(s[conf->db_in_order[a]]);
+	s[conf->db_in_order[a]]=NULL;
+      }
+      i=0;
+      break;
+
+    }
+
+    case TEOF : {
+	
+      /* This can be the first token on a line */
+      if(i>0){
+	error(0,"Not enough parameters in db:%i\n",db_lineno);
+      };
       for(a=0;a<i;a++){
 	free(s[conf->db_in_order[a]]);
       }
@@ -197,17 +220,6 @@ char** db_readline_file(db_config* conf){
       return NULL;
       break;
     }
-
-    case TEOF : {
-
-      error(0,"Not enough parameters in db:%i\n",db_lineno);
-      for(a=0;a<i;a++){
-	free(s[conf->db_in_order[a]]);
-      }
-      free(s);
-      return NULL;
-      break;
-   }
     
     default : {
       
@@ -268,7 +280,7 @@ int db_writeint(long i,FILE* file,int a)
     fprintf(file," ");
   }
   
-  return fprintf(file,"%i",i);
+  return fprintf(file,"%li",i);
   
 }
 
@@ -298,16 +310,14 @@ int db_write_time_base64(time_t i,FILE* file,int a)
   char* tmpstr=NULL;
   int retval=0;
 
+  ptr=(char*)malloc(sizeof(char)*TIMEBUFSIZE);
   if (ptr==NULL) {
-    ptr=(char*)malloc(sizeof(char)*TIMEBUFSIZE);
-    if (ptr==NULL) {
-      error(0,"\nCannot allocate memory..\n");
-      abort();
-    }
+    error(0,"\nCannot allocate memory..\n");
+    abort();
   }
   memset((void*)ptr,0,sizeof(char)*TIMEBUFSIZE);
 
-  sprintf(ptr,"%i",i);
+  sprintf(ptr,"%li",i);
 
   if(a){
     fprintf(file," ");
@@ -317,6 +327,7 @@ int db_write_time_base64(time_t i,FILE* file,int a)
   retval=fprintf(file,tmpstr);
   free(tmpstr);
   free(ptr);
+
   return retval;
 
 }
@@ -327,7 +338,7 @@ int db_writeoct(long i, FILE* file,int a)
     fprintf(file," ");
   }
   
-  return fprintf(file,"%o",i);
+  return fprintf(file,"%lo",i);
   
 }
 
@@ -433,7 +444,7 @@ int db_writeline_file(db_line* line,db_config* conf){
     default : {
       error(0,"Not implemented in db_writeline_file %i\n",
 	    conf->db_out_order[i]);
-      return NULL;
+      return RETFAIL;
     }
     
     }
@@ -441,5 +452,5 @@ int db_writeline_file(db_line* line,db_config* conf){
   }
 
   fprintf(conf->db_out,"\n");
-  return 0;
+  return RETOK;
 }
