@@ -300,10 +300,11 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   if( strncmp(tree->path,"",strlen(tree->path))==0)
     tree->path="/";
   if(!(dirh=opendir(tree->path))){
-    error(5,"traverse_tree():No such directory: %s\n",tree->path);
+    error(5,"traverse_tree():%s: %s\n", strerror(errno),tree->path);
     return file_lst;
   }
   
+  #ifdef HAVE_READDIR_R
   resp=(struct dirent**)
     malloc(sizeof(struct dirent)+_POSIX_PATH_MAX);
   entp=(struct dirent*)
@@ -312,6 +313,15 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   for(rdres=readdir_r(dirh,entp,resp);
       (rdres!=-1&&td!=telldir(dirh));
       rdres=readdir_r(dirh,entp,resp)){
+  #else
+  # ifdef HAVE_READDIR
+  for(entp=readdir(dirh);
+      (entp!=NULL&&td!=telldir(dirh));
+      entp=readdir(dirh)){
+  # else
+  #  error AIDE needs readdir or readdir_r
+  # endif
+  #endif
 
     td=telldir(dirh);
     if(strncmp(entp->d_name,".",1)==0){
@@ -351,6 +361,8 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
 	    file_lst=traverse_tree(a,file_lst,attr);
 	  }
 	}
+      } else {
+	free(fullname);
       }
     } else{ /* This dir is not added by default */
       addfile=0;
@@ -372,6 +384,8 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
 				   matchattr);
 	  }
 	}
+      } else {
+	free(fullname);
       }
       
     }
@@ -381,6 +395,11 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   if(closedir(dirh)==-1){
     error(0,"Closedir() failed for %s\n",tree->path);
   };
+
+  #ifdef HAVE_READDIR_R
+  free(resp);
+  free(entp);
+  #endif
   
   /* All childs are not necessarily checked yet */
   if(tree->childs!=NULL){
